<?php
/*
Name: Filters
Description: Product Filters
Version: 1.0
Compatible: 1.7.4
*/

class lumise_addon_filters extends lumise_addons {
	
	function __construct() {
		
		global $lumise;
		
		/*
		*	Access core js via your JS function name
		*/
		
		$this->access_corejs('lumise_addon_filter');
		
		/*
		*	Add new component, show in left menu of editor and can config in Lumise -> Settings -> Editor
		*/
		
		$this->add_component(array(
			"backgrounds" => array(
				"label" => "Filters",
				"icon" => "lumisex-easel",
				"load" => "filters",
				"class" => "lumise-x-thumbn",
				"content" => $this->render_xitems(array(
					"component" => "filters",
					"search" => true,
					"category" => true,
					"preview" => true,
					"price" => true
				))
			)
		));
		
		/*
		*	Add new left menu in backend	
		*/
		
		$lumise->add_filter('admin_menus', array(&$this, 'admin_menus'));
		
		/*
		*	Display Lumise page in backend
		*/
		
		$lumise->add_filter('admin_page', array(&$this, 'admin_page'));

		// 
		$lumise->add_filter('edit-section', array(&$this, 'save_filter_data'));
		$lumise->add_filter('new-section', array(&$this, 'save_filter_data'));
		$lumise->add_filter('save_reference', array(&$this, 'save_category_filters'));
		
		
		$lumise->add_action('after_field', array(&$this, 'after_field'));
		
			
				
	}

	// public function field_filter_group($args, $data)
	// {
	// 	echo "i am filter";
	// }
	
	public function admin_menus($args) {
		
		global $lumise;
		
		$position = 3;
		
		$new_menu = array(
			"filters" => array(
				'title' => $lumise->lang('Filters'),
				'icon'  => '<i class="fa fa-object-group"></i>',
				'child' => array(
					'filter_groups'   => array(
						'type'   => '',
						'title'  => $lumise->lang('Filter Groups'),
						'link'   => $lumise->cfg->admin_url.'lumise-page=filter_groups',
						'hidden' => false,
					),
					'filter_group' => array(
						'type'   => '',
						'title'  => $lumise->lang('Add New Filter Group'),
						'link'   => $lumise->cfg->admin_url.'lumise-page=filter_group',
						'hidden' => false,
					),
					'filters' => array(
						'type'   => '',
						'title'  => $lumise->lang('Filters'),
						'link'   => $lumise->cfg->admin_url.'lumise-page=filters',
						'hidden' => false,
					),
					'filter' => array(
						'type'   => '',
						'title'  => $lumise->lang('Add New Filter'),
						'link'   => $lumise->cfg->admin_url.'lumise-page=filter',
						'hidden' => false,
					),
					
				),
				'capability' => 'lumise_read_filters'
			)
		);
		
		return array_slice($args, 0, $position, true) + 
			   $new_menu + 
			   array_slice($args, $position, count($args) - 1, true);
			   
	}
	
	public function admin_page($path, $page) {
		
		if ($page == 'filter')
			return dirname(__FILE__).DS.'filter.php';
		else if ($page == 'filters')
			return dirname(__FILE__).DS.'filters.php';
		else if( $page == 'filter_groups' )
			return dirname(__FILE__).DS.'filter_groups.php';
		else if( $page == 'filter_group' ) 
			return dirname(__FILE__).DS.'filter_group.php';
		else return $path;
		
	}
	
	
	

	public function save_filter_data($args, $name) {
		global $lumise;
		
		if( isset($_POST['lumise-section']) && ($_POST['lumise-section']=='filter') ){
			$data = [];
			$data['name'] = $_POST['name'];

			$data['filter_group_id'] = $_POST['filter_group_id'];
			$data['active'] = $_POST['active'] ?? 0;
			$data['order'] = $_POST['order'];

			return $data;
		}
		elseif( isset($_POST['lumise-section']) && ($_POST['lumise-section']=='category') ){
			unset( $args['filters'] );
			return $args;
		}
		elseif( isset($_POST['lumise-section']) && ($_POST['lumise-section']=='product') ){

			unset( $args['filters'] );
			return $args;
		}else{
			return $args;
		}
	}


	public function save_category_filters($args, $id) {
		global $lumise;

		if( isset($_POST['lumise-section']) && ($_POST['lumise-section']=='category') ){
			
			global $lumise_admin, $lumise;

			//echo "<pre>";print_r($args);exit;

			$cates = array();
			$tags  = array();

			if (isset($args['tabs'])) {
				foreach ($args['tabs'] as $key => $tab) {
					foreach ($tab as $key2 => $field) {
						if ($field['type'] == 'filters') {
							array_push($cates, $field);
						}
					}
				}
			} else {
				foreach ($args as $key => $field) {
					if ($field['type'] == 'filters') {
						array_push($cates, $field);
					}
				}
			}

			if (count($cates) > 0) {

				foreach ($cates as $field) {

					if (isset($_POST[$field['name']]) && is_array($_POST[$field['name']])) {
						$post_cates = array_diff($_POST[$field['name']], array(''));
					} else {
						$post_cates = array();
					}

					$lumise->db->rawQuery("DELETE FROM `{$lumise->db->prefix}category_filter` WHERE `category_id`=" . $id);

					if (is_array($post_cates) && count($post_cates) > 0) {
						foreach ($post_cates as $cate) {

							$lumise->db->insert('category_filter', array(
								'category_id' => $id,
								'filter_id'     => $cate,
							));
						}
					}
				}
			}

		}

		if( isset($_POST['lumise-section']) && ($_POST['lumise-section']=='product') ){
			
			global $lumise_admin, $lumise;

			//echo "<pre>";print_r($args);exit;

			$cates = array();
			$tags  = array();

			if (isset($args['tabs'])) {
				foreach ($args['tabs'] as $key => $tab) {
					foreach ($tab as $key2 => $field) {
						if ($field['type'] == 'filters') {
							array_push($cates, $field);
						}
					}
				}
			} else {
				foreach ($args as $key => $field) {
					if ($field['type'] == 'filters') {
						array_push($cates, $field);
					}
				}
			}

			if (count($cates) > 0) {

				foreach ($cates as $field) {

					if (isset($_POST[$field['name']]) && is_array($_POST[$field['name']])) {
						$post_cates = array_diff($_POST[$field['name']], array(''));
					} else {
						$post_cates = array();
					}

					$lumise->db->rawQuery("DELETE FROM `{$lumise->db->prefix}product_filter` WHERE `product_id`=" . $id);

					if (is_array($post_cates) && count($post_cates) > 0) {
						foreach ($post_cates as $cate) {

							$lumise->db->insert('product_filter', array(
								'product_id' => $id,
								'filter_id'     => $cate,
							));
						}
					}
				}
			}

		}

	}

	
	
	/*
		Actions on active or deactive this addon
	*/
	
	static function active() {
		
		global $lumise;
		
		$comps = explode(',', $lumise->cfg->settings['components']);
		
		if (!in_array('filters', $comps))
			array_push($comps, 'filters');
		
		$lumise->set_option('components', implode(',', $comps));
		
		$lumise->db->rawQuery("CREATE TABLE  IF NOT EXISTS `".$lumise->db->prefix."filter_groups` (
			`id` int(11) NOT NULL,
			`name` varchar(255) CHARACTER SET utf8 NOT NULL,
			`filter_type` varchar(10) DEFAULT 'checkbox',
			`active` int(1) DEFAULT NULL,
			`order` int(1) DEFAULT NULL,
			`author` int(11) DEFAULT NULL,
			`created` datetime DEFAULT NULL,
			`updated` datetime DEFAULT NULL
			) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=latin1;");
		
		$lumise->db->rawQuery("ALTER TABLE `".$lumise->db->prefix."filter_groups` ADD PRIMARY KEY (`id`);");
		$lumise->db->rawQuery("ALTER TABLE `".$lumise->db->prefix."filter_groups` CHANGE `id` id int(11) NOT NULL AUTO_INCREMENT;");
		

		//filters
		$lumise->db->rawQuery("CREATE TABLE  IF NOT EXISTS `".$lumise->db->prefix."filters` (
			`id` int(11) NOT NULL,
			`name` varchar(255) CHARACTER SET utf8 NOT NULL,
			`filter_group_id` int(11) NOT NULL,
			`active` int(1) DEFAULT NULL,
			`author` int(11) DEFAULT NULL,
			`order` int(1) DEFAULT NULL
			) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=latin1;");
		
		$lumise->db->rawQuery("ALTER TABLE `".$lumise->db->prefix."filters` ADD PRIMARY KEY (`id`);");
		$lumise->db->rawQuery("ALTER TABLE `".$lumise->db->prefix."filters` CHANGE `id` id int(11) NOT NULL AUTO_INCREMENT;");
		

		//product filter
		$lumise->db->rawQuery("CREATE TABLE  IF NOT EXISTS `".$lumise->db->prefix."product_filter` (
			`filter_id` int(11) NOT NULL,
			`product_id` int(11) NOT NULL
			) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=latin1;");
		
		$lumise->db->rawQuery("ALTER TABLE `".$lumise->db->prefix."filters` ADD PRIMARY KEY (`filter_id`,`product_id`);");

		//category filter
		$lumise->db->rawQuery("CREATE TABLE  IF NOT EXISTS `".$lumise->db->prefix."category_filter` (
			`filter_id` int(11) NOT NULL,
			`category_id` int(11) NOT NULL
			) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=latin1;");
		
		$lumise->db->rawQuery("ALTER TABLE `".$lumise->db->prefix."filters` ADD PRIMARY KEY (`filter_id`,`category_id`);");
		
	}
	
	static function deactive() {
		
		global $lumise;
		
		$comps = explode(',', $lumise->cfg->settings['components']);

		if (in_array('filters', $comps))
			unset($comps[array_search('filters', $comps)]);
		
		$lumise->set_option('components', implode(',', $comps));
		
	}
	
}